/* global HTMLInputElement */
/*jshint globalstrict:true */
'use strict';

document.addEventListener( 'DOMContentLoaded', function () {
	const SEARCH_CONTAINER_ID = 'locrmaps-search';
	const searchElement = document.getElementById( SEARCH_CONTAINER_ID );
	if ( ! ( searchElement instanceof HTMLInputElement ) ) {
		return;
	}

	let updateIconPositionOnSearch = false;

	const dataUpdateIconPositionOnSearchAttr =
		searchElement.attributes.getNamedItem(
			'data-update-icon-position-on-search'
		);
	if ( dataUpdateIconPositionOnSearchAttr instanceof window.Attr ) {
		updateIconPositionOnSearch =
			dataUpdateIconPositionOnSearchAttr.value === 'true';
	}

	searchElement.addEventListener( 'keyup', function ( event ) {
		const trimmedValue = event.target.value.trim();
		if ( trimmedValue.length === 0 ) {
			return;
		}
		if ( event.key !== 'Enter' ) {
			return;
		}

		const urlParams = new URLSearchParams();
		urlParams.set( 'text', trimmedValue );
		const url = `https://geocode.locr.com/api/pelias/search?${ urlParams.toString() }`;
		fetch( url )
			.then( ( response ) => response.json() )
			.then( ( data ) => {
				if ( ! data ) {
					window.console.warn( 'No data received' );
					return;
				}

				let customEventType = 'locrmaps-unknown';
				const eventData = {
					detail: {},
				};

				if ( data.features && data.features.length > 0 ) {
					customEventType = 'locr.locrmaps.set-center';
					const feature = data.features[ 0 ];
					if ( feature.bbox && feature.bbox.length === 4 ) {
						customEventType = 'locr.locrmaps.fit-bounds';
						eventData.detail.bounds = {
							south: feature.bbox[ 1 ],
							west: feature.bbox[ 0 ],
							north: feature.bbox[ 3 ],
							east: feature.bbox[ 2 ],
						};
					}

					eventData.detail.center = {
						latitude: feature.geometry.coordinates[ 1 ],
						longitude: feature.geometry.coordinates[ 0 ],
					};

					if ( ! eventData.detail.bounds ) {
						eventData.detail.zoom = 18;
					}
					if ( updateIconPositionOnSearch ) {
						eventData.detail.updateIconPosition = true;
					}
				}

				document.dispatchEvent(
					new CustomEvent( 'locr.locrmaps.update-icon-position', {
						...eventData,
					} )
				);
				document.dispatchEvent(
					new CustomEvent( customEventType, { ...eventData } )
				);
			} );
	} );
} );
